@@ -1,7 +1,7 @@
 import os
 from pathlib import Path
 from tempfile import NamedTemporaryFile
-from typing import Optional, List
+from typing import List, Optional
 
 from commitizen import cmd
 
@@ -64,7 +64,7 @@ def get_commits(
     git_log_cmd = f"git log --pretty={log_format}{delimiter}"
 
     if start:
-        c = cmd.run(f"{git_log_cmd} {start}...{end}")
+        c = cmd.run(f"{git_log_cmd} {start}..{end}")
     else:
         c = cmd.run(f"{git_log_cmd} {end}")
 
